@@ -218,11 +218,12 @@ while (!empty($cmd)) {
                 echo '<th>' . _('Created') . '</th>';
                 echo '<th>' . _('Actions') . '</th></tr></thead>';
                 echo '<tbody>';
+                $oldcategory = null;
                 while ($row = mysql_fetch_assoc($q)) {
                     if ($oldcategory != $row['category'] && CONFIG_get('main_style')==1) {
                         echo '<tr><td colspan="4"><b>'. htmlspecialchars($categories[$row['category']]) .'</b></td></tr>'."\n";
                     }
-            $oldcategory = $row['category'];
+                    $oldcategory = $row['category'];
                     echo '<tr class="priority' . $row['priority'];
                     if (!is_null($row['closed']) && $row['closed'] != 0) {
                         echo ' closed';
@@ -757,7 +758,7 @@ while (!empty($cmd)) {
             header('Content-Type: text/plain; charset=utf-8');
             header('Content-Disposition: attachment; filename="ukolovnik.csv"');
 
-            $q = SQL_do('SELECT id,category,UNIX_TIMESTAMP(created) AS created,priority,title,description,UNIX_TIMESTAMP(closed) AS closed FROM ' . $GLOBALS['table_prefix'] . 'tasks ' . $filter . ' ORDER BY priority DESC, created ASC');
+            $q = SQL_do('SELECT id,category,UNIX_TIMESTAMP(created) AS created,priority,title,description,UNIX_TIMESTAMP(closed) AS closed FROM ' . $GLOBALS['table_prefix'] . 'tasks ORDER BY priority DESC, created ASC');
             echo "priority,title,description,category,created,closed\n";
             if (mysql_num_rows($q) > 0) {
                 while ($row = mysql_fetch_assoc($q)) {
